@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Matthew Williams <matt@milliams.com>            *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Matthew Williams <matt@milliams.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 //header
 #include "ksquareswindow.h"
@@ -289,15 +286,15 @@ void KSquaresWindow::aiChooseLine()
 
 void KSquaresWindow::setupActions()
 {
-    KStandardGameAction::gameNew(this, SLOT(gameNew()), actionCollection());
-    QAction *resetGame = KStandardGameAction::restart(this, SLOT(gameReset()), actionCollection());
+    KStandardGameAction::gameNew(this, &KSquaresWindow::gameNew, actionCollection());
+    QAction *resetGame = KStandardGameAction::restart(this, &KSquaresWindow::gameReset, actionCollection());
     resetGame->setStatusTip(i18n("Start a new game with the current settings"));
 
-    KStandardGameAction::highscores(this, SLOT(showHighscores()), actionCollection());
-    KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+    KStandardGameAction::highscores(this, &KSquaresWindow::showHighscores, actionCollection());
+    KStandardGameAction::quit(this, &QWidget::close, actionCollection());
 
     // Preferences
-    KStandardAction::preferences(this, SLOT(optionsPreferences()), actionCollection());
+    KStandardAction::preferences(this, &KSquaresWindow::optionsPreferences, actionCollection());
 
     setupGUI();
 }
